@@ -1,9 +1,12 @@
 import importlib
 import sys
 
+from ptera import Probe
+
+from .analyze import viz
 from .debug import SnekTalkDb
 from .evaluator import Evaluator
-from .repr import inject, snekprint as print
+from .lib import inject, snekprint as print
 from .server import serve
 from .session import current_session
 from .utils import Interactor, pastecode, pastevar
