@@ -1,12 +1,16 @@
+import ast
 import types
-from dataclasses import dataclass
-from itertools import count, product
+from itertools import product
+from typing import Union
 
-from hrepr import H, Interface, standard_terminal
+from hrepr import H, standard_terminal
 from jurigged import make_recoder
+from jurigged.codetools import Extent
 from ovld import OvldMC, exactly, ovld
+from ptera import Probe
 
-from ..utils import Interactor, ObjectFields, format_libpath, represents
+from ..analyze import viz
+from ..utils import Interactor, ObjectFields, format_libpath, newvar, pastecode
 
 ########
 # edit #
@@ -23,14 +27,15 @@ def edit(self, obj, **kwargs):
 
 @ovld
 def edit(
-    obj: (type, types.FunctionType, types.CodeType, types.ModuleType), **kwargs
+    obj: Union[type, types.FunctionType, types.CodeType, types.ModuleType],
+    **kwargs,
 ):
     recoder = make_recoder(obj)
     return recoder and SnekRecoder(recoder, obj, **kwargs)
 
 
 @ovld
-def edit(obj: (tuple, int, float, bool, type(None), frozenset), **kwargs):
+def edit(obj: Union[tuple, int, float, bool, type(None), frozenset], **kwargs):
     raise ValueError(f"Cannot edit data with type {type(obj).__qualname__}")
 
 
@@ -44,6 +49,60 @@ def edit(obj: object, **kwargs):
 ######################
 
 
+@ovld
+def _probables(self, seq: list, path):
+    results = set()
+    for node in seq:
+        results |= self(node, path)
+    return results
+
+
+@ovld
+def _probables(self, node: Union[ast.FunctionDef, ast.AsyncFunctionDef], path):
+    func_path = (*path, node.name)
+    return (
+        self(node.body, func_path)
+        | self(node.args.args, func_path)
+        | self(node.args.posonlyargs, func_path)
+        | self(node.args.kwonlyargs, func_path)
+        | self(node.args.kwarg, func_path)
+        | self(node.args.vararg, func_path)
+        | self(node.decorator_list, path)
+        | self(node.args.defaults, path)
+        | self(node.args.kw_defaults, path)
+    )
+
+
+@ovld
+def _probables(self, node: ast.ClassDef, path):
+    cls_path = (*path, node.name)
+    return self(node.body, cls_path) | self(node.decorator_list, path)
+
+
+@ovld
+def _probables(self, node: ast.arg, path):
+    return {(*path, node.arg)}
+
+
+@ovld
+def _probables(self, node: ast.Name, path):
+    if isinstance(node.ctx, ast.Store):
+        return {(*path, node.id)}
+    else:
+        return set()
+
+
+@ovld
+def _probables(self, node: ast.AST, path):
+    return self(list(ast.iter_child_nodes(node)), path)
+
+
+@ovld  # pragma: no cover
+def _probables(self, thing: object, path):
+    # Just in case
+    return set()
+
+
 class SnekRecoder(Interactor):
 
     js_constructor = "LiveEditor"
@@ -86,6 +145,36 @@ class SnekRecoder(Interactor):
         if self.py_save(new_source):
             self.recoder.commit()
 
+    def py_probe(self, selection):
+        focus = self.recoder.focus
+        baseline = focus.stashed
+        ext = Extent(
+            filename=baseline.filename,
+            lineno=selection["startLineNumber"],
+            col_offset=selection["startColumn"],
+            end_lineno=selection["endLineNumber"],
+            end_col_offset=selection["endColumn"],
+        )
+        lines = self.recoder.focus.codestring.split("\n")
+        text = lines[ext.lineno - 1][
+            ext.col_offset - 1 : ext.end_col_offset - 1
+        ]
+        probables = [p for p in _probables(focus.node, ()) if p[-1] == text]
+        *path, varname = probables[0]
+
+        hier = list(focus.hierarchy())
+        names = [part.name for part in reversed(hier)]
+        names += path[len(names) - 1 :]
+        selector = "/" + "/".join(names) + " > " + varname
+
+        pastecode(
+            f'viz({newvar("probe")} := Probe("{selector}"))',
+            vars={
+                "Probe": (Probe, "from ptera import Probe"),
+                "viz": (viz, "from snektalk import viz"),
+            },
+        )
+
 
 ##########################
 # Data structures editor #
@@ -169,20 +258,22 @@ class EditableRepr(metaclass=OvldMC):
     @ovld
     def _run(
         self,
-        s: (
+        s: Union[
             exactly(str),
             exactly(type(None)),
             exactly(bool),
             exactly(int),
             exactly(float),
-        ),
+        ],
         *,
         depth,
     ):
         return H.atom(repr(s))
 
     @ovld
-    def _run(self, s: (types.FunctionType, types.ModuleType, type), *, depth):
+    def _run(
+        self, s: Union[types.FunctionType, types.ModuleType, type], *, depth
+    ):
         return self.ref(s)
 
     @ovld
@@ -315,13 +406,13 @@ def _merge(self, obj: list, m1: list, m2):
 @ovld
 def _merge(
     self,
-    obj: (
+    obj: Union[
         exactly(str),
         exactly(type(None)),
         exactly(bool),
         exactly(int),
         exactly(float),
-    ),
+    ],
     m1,
     m2,
 ):
